@@ -2,7 +2,7 @@ package Mojolicious::Plugin::FormChecker;
 
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '1.001001'; # VERSION
+our $VERSION = '1.001002'; # VERSION
 
 sub register {
     my ($self, $app) = @_;
@@ -37,7 +37,7 @@ sub _perform_checks {
 
     %conf = (
         all_errors  => 1, # TODO: get rid of this and always do all_errors
-        error_class => 'error',
+        error_class => 'alert alert-extra-danger',
         %conf,
     );
 
@@ -75,7 +75,8 @@ sub _perform_checks {
         form_checker_error => $self->_error,
         form_checker_error_wrapped =>
             join "\n", map qq{<p class="} . $conf{error_class}
-                . qq{">$_</p>}, @{ $self->_error || [] },
+                . q{"><i class="glyphicon glyphicon-warning-sign"></i> }
+                . qq{$_</p>}, @{ $self->_error || [] },
     );
 }
 
@@ -311,7 +312,7 @@ validating query parameters input.
 
 =head1 METHODS
 
-L<Mojolicious::Plugin::FormValidator> inherits all methods from
+L<Mojolicious::Plugin::FormChecker> inherits all methods from
 L<Mojolicious::Plugin> and implements the following new ones.
 
 =head2 register
@@ -325,7 +326,7 @@ Register plugin in L<Mojolicious> application.
 =head2 C<form_checker>
 
     $c->form_checker(
-        error_class => 'error',
+        error_class => 'alert alert-extra-danger',
         rules => {
             name => { max => 2, },
             email => { max => 200, },
@@ -600,7 +601,7 @@ value.
     min_error => 'Too short :(',
 
 This is the error for C<min> rule. B<Defaults to:>
-C<Parameter $name must be at least $rule->{min} characters long>
+C<< Parameter $name must be at least $min characters long >
 
 =head4 C<code_error>
 
